import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/chen-ding-71/3e4e5c6a6f9248bdece950069e3d2aae/raw/38bc58dc4d87575d0207582efb9e5996f8232e64/Suicide_Generation.csv';
const width = 960;
const height = 500;
const margin = { top: 100, right: 20, bottom: 20, left: 150 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvUrl).then(data => {
      setData(data.slice(0, 30));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Generation))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d['Suicide_No'])])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <text x="30" y="-20" font-family="sans-serif" fontSize="40" fill="DarkBlue">
          Number of Suicide across Generation
        </text>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="black" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".71em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            fill="gray"
            stroke="white"
            stroke-width="2"
            key={d.Generation}
            x={0}
            y={yScale(d.Generation)}
            width={xScale(d['Suicide_No'])}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
